# <a name="POIM-PDU-Description"></a>ASN.1 module POIM-PDU-Description
OID: _{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) poi(103916) poim(0) major-version-1 (1) minor-version-1 (1)}_

## Imports:
* **[ETSI-ITS-CDD](ETSI-ITS-CDD.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (102894) cdd (2) major-version-4 (4) minor-version-1 (1)} WITH SUCCESSORS*<br/>
* **[POIM-ParkingAvailability](POIM-ParkingAvailability.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) poi(103916) parkingAvailability(1) major-version-1 (1) minor-version-1 (1)} WITH SUCCESSORS*<br/>
## Data Elements:
### <a name="POIM"></a>POIM
This type represents the POIM PDU.

 It shall include the following components:

* _header_ of type [**ItsPduHeader**](ETSI-ITS-CDD.md#ItsPduHeader)  (WITH COMPONENTS {... , protocolVersion (1), messageId(poi)})<br>
  the header of the POIM PDU.

* _payload_ of type [**WrappedPoiInformationBlocks**](#WrappedPoiInformationBlocks) <br>
  the payload of the POIM PDU.

```asn1
POIM ::= SEQUENCE { 
    header  	ItsPduHeader (WITH COMPONENTS {... , protocolVersion (1), messageId(poi)}),        
    payload     WrappedPoiInformationBlocks
}
```

### <a name="WrappedPoiInformationBlocks"></a>WrappedPoiInformationBlocks
This DF represents a list of POI information blocks, each with their type identifier.
```asn1
WrappedPoiInformationBlocks::= SEQUENCE (SIZE (1..8,...)) OF WrappedPoiInformationBlock
```

### <a name="BLOCK-TYPE"></a>BLOCK-TYPE
This information object class is an abstract template to instantiate POI Information Blocks.

 It shall include the following components:

* _id_ of type [**PoiType**](#PoiType) <br>
  the identifier of the block type.

* Type<br>
  the block content.

```asn1
BLOCK-TYPE ::= CLASS {
    &id        PoiType,
    &Content
} WITH SYNTAX {&Content IDENTIFIED BY &id}
```

### <a name="PoiType"></a>PoiType
This DE represents the identifier of the container type.
```asn1
PoiType::= INTEGER(1..128,...)
```

These value assignements represent specific values of the block type identifier.

```asn1
parkingAvailability    PoiType ::= 1
```

### <a name="PoiInformationSet"></a>PoiInformationSet
This information object set represents the association between the block type and the block content.
```asn1
PoiInformationSet BLOCK-TYPE ::= {
   {ParkingAvailabilityBlock    IDENTIFIED BY parkingAvailability}, ...
}
```

### <a name="WrappedPoiInformationBlock"></a>WrappedPoiInformationBlock
This DF represents a POI Information Block preceded by its type identifier and a lenght indicator.

 It shall include the following components:

* _poiType_ of type [**BLOCK-TYPE**](#BLOCK-TYPE) .&id({PoiInformationSet})<br>
  the identifier of the POI Information Block type.

* _poiBlock_ of type [**BLOCK-TYPE**](#BLOCK-TYPE) .&Content({PoiInformationSet}{@poiType})<br>
  the POI Information Block.

```asn1
WrappedPoiInformationBlock ::= SEQUENCE {
    poiType      BLOCK-TYPE.&id({PoiInformationSet}),
    poiBlock     BLOCK-TYPE.&Content({PoiInformationSet}{@poiType})
}
```

### <a name="PoiBlockManagementContainer"></a>PoiBlockManagementContainer
This type represents the common management container of the POI Information Blocks. 

 It shall include the following components:

* _serviceProviderId_ of type [**Provider**](ETSI-ITS-CDD.md#Provider) <br>
  identifier of the organization that provided the POI Information Block.

* _blockIdentificationNumber_ of type [**Identifier2B**](ETSI-ITS-CDD.md#Identifier2B) <br>
  identifier of the POI Information Block, as assigned by the organization identified in serviceProviderId.

* _timestamp_ of type [**TimestampIts**](ETSI-ITS-CDD.md#TimestampIts) <br>
  timestamp of the generation or last change of the POI Information Block

* _linkedIvims_ of type [**IvimReferences**](ETSI-ITS-CDD.md#IvimReferences)  OPTIONAL<br>
  the optional list of references to IVIMs that are semantically connected because providing signage information applying to the POI.

* _linkedMapems_ of type [**MapReferences**](ETSI-ITS-CDD.md#MapReferences)  OPTIONAL<br>
* linkedMapem<br>
  the optional list of references to MAPEMs that are semantically connected because providing information applying to the POI.

```asn1
PoiBlockManagementContainer::= SEQUENCE {
	serviceProviderId			Provider, 
	blockIdentificationNumber	Identifier2B,
	timestamp					TimestampIts,
	linkedIvims                 IvimReferences OPTIONAL,
    linkedMapems                MapReferences OPTIONAL,
    ...  
}
```

### <a name="RelatedPoiInfoBlock"></a>RelatedPoiInfoBlock
This type can be used to reference to other related POI Information Blocks. 

 It shall include the following components:

* _poiInfoBlockType_ of type [**PoiType**](#PoiType) <br>
  the type of related POI Information Blocks

* _serviceProviderId_ of type [**Provider**](ETSI-ITS-CDD.md#Provider) <br>
  identifier of the organization that provided the related POI Information Block.

* _blockIdentificationNumber_ of type [**Identifier2B**](ETSI-ITS-CDD.md#Identifier2B) <br>
  identifier of the related POI Information Block, as assigned by the organization identified in serviceProviderId.

* _timestamp_ of type [**TimestampIts**](ETSI-ITS-CDD.md#TimestampIts)  OPTIONAL<br>
  optional timestamp of the generation or last change of the related POI Information Block

```asn1
RelatedPoiInfoBlock::= SEQUENCE{
   poiInfoBlockType             PoiType,
   serviceProviderId			Provider, 
   blockIdentificationNumber	Identifier2B, 
   timestamp					TimestampIts OPTIONAL,
    ...
}
```

### <a name="RelatedPoiInfoBlockContainer"></a>RelatedPoiInfoBlockContainer
This DF shall contain a list of [**RelatedPoiInfoBlock**](#RelatedPoiInfoBlock) and represents a commmon container to refer to other POI Information Blocks.
```asn1
RelatedPoiInfoBlockContainer::= SEQUENCE OF RelatedPoiInfoBlock
```



